@@ -27,7 +27,7 @@ use Config::IniFiles;
 #inherits Lemonldap::NG::Common::Conf::Backends::SOAP
 #inherits Lemonldap::NG::Common::Conf::Backends::LDAP
 
-our $VERSION = '2.0.6';
+our $VERSION = '2.0.12';
 our $msg     = '';
 our $iniObj;
 
@@ -87,7 +87,7 @@ sub new {
           unless $self->{type} =~ /^Lemonldap::/;
         eval "require $self->{type}";
         if ($@) {
-            $msg .= "Error: Unknown package $self->{type}.\n";
+            $msg .= "Error: failed to load $self->{type}: \n $@";
             return 0;
         }
         return 0 unless $self->prereq;
@@ -119,10 +119,13 @@ sub saveConf {
     my ( $self, $conf, %args ) = @_;
 
     my $last = $self->lastCfg;
+    return UNKNOWN_ERROR if $last < 1;
 
     # If configuration was modified, return an error
     if ( not $args{force} ) {
-        return CONFIG_WAS_CHANGED if ( $conf->{cfgNum} != $last );
+        return CONFIG_WAS_CHANGED
+          if ( $conf->{cfgNum} ne $last
+            || $args{cfgDate} && $args{cfgDate} ne $args{currentCfgDate} );
         return DATABASE_LOCKED if ( $self->isLocked() or not $self->lock() );
     }
     $conf->{cfgNum} = $last + 1 unless ( $args{cfgNumFixed} );
@@ -304,7 +307,8 @@ sub getLocalConf {
         $cfg = Config::IniFiles->new( -file => $file, -allowcontinue => 1 );
 
         unless ( defined $cfg ) {
-            $msg .= "Local config error: " . @Config::IniFiles::errors . "\n";
+            $msg .= "Local config error: "
+              . ( join "\n", @Config::IniFiles::errors ) . "\n";
             return $r;
         }
 
@@ -334,7 +338,7 @@ sub getLocalConf {
             {
                 eval "\$r->{$_} = $r->{$_}";
                 if ($@) {
-                    $msg .= "Warning: error in file $file: $@.\n";
+                    $msg .= "Warn: error in file $file: $@.\n";
                     return $r;
                 }
             }
@@ -356,7 +360,7 @@ sub getLocalConf {
         if ( $r->{$_} =~ /^[{\[].*[}\]]$/ || $r->{$_} =~ /^sub\s*{.*}$/ ) {
             eval "\$r->{$_} = $r->{$_}";
             if ($@) {
-                $msg .= "Warning: error in file $file: $@.\n";
+                $msg .= "Warn: error in file $file: $@.\n";
                 return $r;
             }
         }
@@ -392,6 +396,7 @@ sub getDBConf {
           : $a[0];
     }
     my $conf = $self->load( $args->{cfgNum} );
+    return undef if $conf == "-1";
     $msg .= "Get configuration $conf->{cfgNum}.\n"
       if ( defined $conf->{cfgNum} );
     return $conf;
@@ -410,7 +415,11 @@ sub _launch {
         alarm 0;
         die $@ if $@;
     };
-    $msg .= $@ if $@;
+    if($@) {
+        $msg .= $@;
+        print STDERR "MSG $msg\n";
+        return undef;
+    }
     return wantarray ? (@res) : $res[0];
 }
 
@@ -479,7 +488,7 @@ sub delete {
     my ( $self, $c ) = @_;
     my @a = $self->available();
     if ( grep( /^$c$/, @a ) ) {
-        return $self->_launch( 'delete', $self, $c );
+        return $self->_launch( 'delete', $c );
     }
     else {
         return 0;
